---
title: 에스크로 서비스 안내
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
tags:
  - 공통
pgCompanies:
  - 공통
searchTags:
  - 에스크로
datetime: 2024-06-11T06:06:47.384Z
---

### **에스크로란?**

소비자가 구매의 안전을 위해 원할 경우 공신력 있는 결제대금예치업자 (은행, PG업체 등을 말함, [「전자상거래 등에서의 소비자보호에 관한 법률 시행령」 제19조의3](http://www.law.go.kr/LSW/LsiJoLinkP.do?docType=JO\&lsNm=%EC%A0%84%EC%9E%90%EC%83%81%EA%B1%B0%EB%9E%98+%EB%93%B1%EC%97%90%EC%84%9C%EC%9D%98+%EC%86%8C%EB%B9%84%EC%9E%90%EB%B3%B4%ED%98%B8%EC%97%90+%EA%B4%80%ED%95%9C+%EB%B2%95%EB%A5%A0+%EC%8B%9C%ED%96%89%EB%A0%B9\&joNo=001900003\&languageType=KO\&paras=1)제1항)가 소비자의 결제대금을 맡아두고 있다가 인터넷쇼핑몰 사업자의 상품배송이 완료된 뒤 사업자에게 대금을 지급하는 거래안전장치를 의미합니다.

인터넷쇼핑몰 사업자는 소비자의 구매대금 결제 시 소비자가 결제대금예치제도를 선택할 경우 이를 이용할 수 있도록 사전에 결제대금예치업자와 계약을 체결해야 합니다.

에스크로 서비스는 현금성 결제수단에 대해서는 최소금액 상관없이 의무가입 사항이며, PG사와의 계약시 현금성 결제수단을 신청하면 **반드시** 계약이 체결됩니다.

다만, 아래와 같이 일부 상품종류에 대해서는 의무가입이 면제가 됩니다.

- 배송이 확인되지 않는 비실물거래
- 신용카드 거래
- 일정 기간에 걸쳐 서비스가 분할 공급되는 형태

### **에스크로 설정여부 확인하기**

에스크로 서비스는 PG사와 계약시 에스크로 구매안전서비스 설정이 가능합니다.\
기 가입된  고객사의 경우 이용하고 계시는 PG사 상점관리자페이지 접속하시어 에스크로 서비스 설정여부 확인이 가능합니다. (미신청된 경우 대부분 PG사 상점관리자페이지 내에서 에스크로 서비스 신청이 가능합니다)

### **에스크로 결제 프로세스**

에스크로 프로세스는 기본적으로 결제 -> 배송등록 > 구매결정 > 대금지급 의 순서로 진행됩니다.

- 결제 연동

<Indent level="1">

- 결제가 완료되면 가맹점에 결제완료(paid)로 결과를 보내 드립니다.
- 결제창 연동을 위해 javascript에서 호출하시는 함수의 파라메터로 escrow : true 옵션을 주시면 에스크로 모드로 동작하게 되니 다른 파라메터는 동일하게 주시고 escrow : true 옵션만 추가하시어 이용해주시길 바랍니다.

</Indent>

<Callout content="e.g)
IMP.request_pay({
//다른 파라메터는 생략
escrow: true
})
" />

- 배송등록

<Indent level="1">

- 가상계좌의 경우 고객이 실입금하시어 포트원 webhook으로 입금통지(status : paid)를 받으신 후 포트원 API  [POST/escrows/logis/](https://api.iamport.kr) 로 등록이 가능합니다.
- 결제요청시 "escrow : true" 옵션을 지정한 거래건에 대해 배송등록 처리를 해 주셔야 하고 에스크로 옵션 지정하지 않은 일반거래건에 대해서는 해당 절차가 필요하지 않습니다.

</Indent>

- 구매확정, 구매거절

<Indent level="1">

- PG사에서 1차적으로 고객 이메일로 구매확정 안내 이메일이 발송되어 이메일에서 구매확정처리가 가능하며 고객이 구매확정처리를 하지 않은 경우 배송완료일 기준 D+3영업일 경과 후에 자동구매확정처리가 됩니다.
  (배송추적이 불가능한 경우, 배송등록일 기준 D+6 영업일 자동구매확정 처리)

</Indent>

- 대금정산

<Indent level="1">

- 구매확정 후 PG사에서 사업장으로 정산하여 지급 처리 됩니다.

</Indent>

- 기타

<Indent level="1">

- 에스크로 서비스 특성상 구매확정 이전에는 부분취소가 불가 합니다.

</Indent>

<Callout title="에스크로 관련 API 보러가기 ↗" />
